@@ -1,6 +1,25 @@
 import markdown
 from xhtml2pdf import pisa 
 
+def _extract_filename_from_filepath(filepath):
+    
+    if(filepath.rfind('\\') == -1 and \
+        filepath.rfind('/') == -1):
+        str_split = filepath.split('.')
+        filename = str_split[0]
+
+    if(filepath.rfind('\\') != -1):
+        lwr_bound = filepath.rfind('\\')
+        upper_bound = filepath.find('.')
+        filename = filepath[(lwr_bound+1):(upper_bound)]
+
+    if(filepath.rfind('/') != -1):
+        lwr_bound = filepath.rfind('/')
+        upper_bound = filepath.find('.')
+        filename = filepath[(lwr_bound+1):(upper_bound)]
+
+    return(filename)
+
 def convert(input_md_filepath, output_pdf_filename=None):
     """Simply convert an md file to pdf. You can choose the output name,
     but the default is the name of the input. 
@@ -20,8 +39,7 @@ def convert(input_md_filepath, output_pdf_filename=None):
 
 
     if(output_pdf_filename == None):
-        str_split = output_pdf_filename.split('.')
-        output_pdf_filename = str_split[0] + '.pdf'
+        output_pdf_filename = _extract_filename_from_filepath(input_md_filepath) + '.pdf'
     # open output file for writing (truncated binary)
     result_file = open(output_pdf_filename, "w+b")
 
