@@ -14,12 +14,12 @@ def feed_template_md(output_filename, input_obj):
     Returns:
         [Boolean]: Boolean to make sure that the file is closed on our way out.
     """
-    if(type(input_obj) == str | type(input_obj) == pd.core.fram.DataFrame):
+    if(type(input_obj) != str and type(input_obj) != pd.core.frame.DataFrame):
         raise ValueError('Input must be a str or a pandas.DataFrame')
 
     if(type(input_obj) == str):
         df = pd.read_csv(input_obj)
-    if(type(input_obj) == pd.core.fram.DataFrame):
+    if(type(input_obj) == pd.core.frame.DataFrame):
         df = input_obj
 
     f = io.open(output_filename, "w", encoding="utf-8")
